==> cv-library-react-web-0.1.2.tgz: package/src/components/LoginForm/LoginForm.js <==
import React from 'react';
import PropTypes from 'prop-types';

import TextLabel from '../TextLabel/TextLabel';
import TextField from '../TextField/TextField';
import Switch from '../Toggle/Toggle';
import Button from '../Button/Button';

import getStyles from './LoginForm.styles';

const LoginForm = (props) => {
    const {
        contextStyles,
        errors,
        isLoggingIn,
        onLoginPress,
        onPasswordChange,
        onSavePasswordChange,
        onShowPasswordChange,
        onUserNameChange,
        password,
        savePassword,
        showPassword,
        userName,
    } = props;

    const styles = getStyles(contextStyles);

    return (
        <div style={ styles.container }>
            <h2 style={ styles.heading }>Login</h2>

            <div style={ styles.userNameContainer }>
                <TextLabel>Username</TextLabel>
                <TextField
                    onChange={ onUserNameChange }
                    value={ userName }
                    autoFocus />
                { errors && errors['userName'] &&
                <TextLabel
                    error
                    contextStyles={ {
                        container: styles.error,
                    } }>
                    { errors['userName'] }
                </TextLabel>
                }
            </div>

            <div style={ styles.passwordContainer }>
                <TextLabel>Password</TextLabel>
                <TextField
                    onChange={ onPasswordChange }
                    value={ password }
                    type={ showPassword ? 'text' : 'password' } />
                { errors && errors['password'] &&
                <TextLabel
                    error
                    contextStyles={ {
                        container: styles.error,
                    } }>
                    { errors['password'] }
                </TextLabel>
                }
            </div>

            <div style={ styles.savePasswordContainer }>
                <Switch
                    checked={ savePassword }
                    onChange={ onSavePasswordChange } />
                <TextLabel>Save Password</TextLabel>
            </div>

            <div style={ styles.showPasswordContainer }>
                <Switch
                    checked={ showPassword }
                    onChange={ onShowPasswordChange } />
                <TextLabel>Show Password</TextLabel>
            </div>

            <Button
                contextStyles={ {
                    container: styles.button,
                    text: styles.buttonText,
                } }
                onClick={ onLoginPress }
                disabled={ isLoggingIn || (!userName.trim() && !password.trim()) }
                text="Login" />
        </div>
    );
};

LoginForm.propTypes = {
    contextStyles: PropTypes.shape({
        container: PropTypes.object,
        heading: PropTypes.object,
    }),
    isLoggingIn: PropTypes.bool,
    onLoginPress: PropTypes.func.isRequired,
    onPasswordChange: PropTypes.func.isRequired,
    onSavePasswordChange: PropTypes.func.isRequired,
    onShowPasswordChange: PropTypes.func.isRequired,
    onUserNameChange: PropTypes.func.isRequired,
    userName: PropTypes.string.isRequired,
    password: PropTypes.string.isRequired,
    savePassword: PropTypes.bool.isRequired,
    showPassword: PropTypes.bool.isRequired,
    errors: PropTypes.object,
};

LoginForm.defaultProps = {
    contextStyles: {},
    errors: {
        userName: '',
        password: '',
    },
};

export default LoginForm;

==> cv-library-react-web-0.1.7.tgz: package/src/components/LoginForm/LoginForm.js <==
import React from 'react';
import PropTypes from 'prop-types';

import TextLabel from '../TextLabel/TextLabel';
import TextField from '../TextField/TextField';
import Switch from '../Toggle/Toggle';
import Button from '../Button/Button';

import getStyles from './LoginForm.styles';

const LoginForm = (props) => {
    const {
        contextStyles,
        errors,
        isLoggingIn,
        onLoginPress,
        onPasswordChange,
        onSavePasswordChange,
        onShowPasswordChange,
        onUserNameChange,
        password,
        savePassword,
        showPassword,
        userName,
    } = props;

    const styles = getStyles(contextStyles);

    return (
        <div style={ styles.container }>
            <h2 style={ styles.heading }>Login</h2>

            <div style={ styles.userNameContainer }>
                <TextLabel>Username</TextLabel>
                <TextField
                    onChange={ onUserNameChange }
                    value={ userName }
                    autoFocus />
                { errors && errors['userName'] &&
                    <TextLabel
                        error
                        contextStyles={ {
                            container: styles.error,
                        } }>
                        { errors['userName'] }
                    </TextLabel>
                }
            </div>

            <div style={ styles.passwordContainer }>
                <TextLabel>Password</TextLabel>
                <TextField
                    onChange={ onPasswordChange }
                    value={ password }
                    type={ showPassword ? 'text' : 'password' } />
                { errors && errors['password'] &&
                    <TextLabel
                        error
                        contextStyles={ {
                            container: styles.error,
                        } }>
                        { errors['password'] }
                    </TextLabel>
                }
            </div>

            <div style={ styles.savePasswordContainer }>
                <Switch
                    checked={ savePassword }
                    onChange={ onSavePasswordChange } />
                <TextLabel>Save Password</TextLabel>
            </div>

            <div style={ styles.showPasswordContainer }>
                <Switch
                    checked={ showPassword }
                    onChange={ onShowPasswordChange } />
                <TextLabel>Show Password</TextLabel>
            </div>

            { errors && errors['main'] &&
                <TextLabel
                    error
                    contextStyles={ {
                        container: styles.error,
                    } }>
                    { errors['main'] }
                </TextLabel>
            }
            <Button
                contextStyles={ {
                    container: styles.button,
                    text: styles.buttonText,
                } }
                onClick={ onLoginPress }
                disabled={ isLoggingIn || (!userName.trim() && !password.trim()) }
                text="Login" />
        </div>
    );
};

LoginForm.propTypes = {
    contextStyles: PropTypes.shape({
        container: PropTypes.object,
        heading: PropTypes.object,
    }),
    errors: PropTypes.shape({
        main: PropTypes.string,
        password: PropTypes.string,
        userName: PropTypes.string,
    }),
    isLoggingIn: PropTypes.bool,
    onLoginPress: PropTypes.func.isRequired,
    onPasswordChange: PropTypes.func.isRequired,
    onSavePasswordChange: PropTypes.func.isRequired,
    onShowPasswordChange: PropTypes.func.isRequired,
    onUserNameChange: PropTypes.func.isRequired,
    password: PropTypes.string.isRequired,
    savePassword: PropTypes.bool.isRequired,
    showPassword: PropTypes.bool.isRequired,
    userName: PropTypes.string.isRequired,
};

LoginForm.defaultProps = {
    contextStyles: {},
};

export default LoginForm;
